==> CGAL-5.1-doc_html.tar.xz: doc_html/Polyhedron/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.1 - 3D Polyhedral Surface", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#sectionPolyIntro", null ],
      [ "Definition", "index.html#PolyhedronDefinition", null ],
      [ "Example Programs", "index.html#PolyhedronExample", [
        [ "First Example Using Defaults", "index.html#PolyhedronFirstExampleUsingDefaults", null ],
        [ "Example with Geometry in Vertices", "index.html#PolyhedronExamplewithGeometryinVertices", null ],
        [ "Example for Affine Transformation", "index.html#PolyhedronExampleforAffineTransformation", null ],
        [ "Example Computing Plane Equations", "index.html#PolyhedronExampleComputingPlaneEquations", null ],
        [ "Example with a Vector Instead of a List Representation", "index.html#sectionPolyVector", null ],
        [ "Example with Circulator Writing Object File Format (OFF)", "index.html#PolyhedronExamplewithCirculatorWritingObject", null ],
        [ "Example Using Euler Operators to Build a Cube", "index.html#PolyhedronExampleUsingEulerOperatorstoBuild", null ],
        [ "Draw a Polyhedron", "index.html#PolyhedronDraw", null ]
      ] ],
      [ "File I/O", "index.html#PolyhedronFile", null ],
      [ "Extending Vertices, Halfedges, and Facets", "index.html#PolyhedronExtending", null ],
      [ "Advanced Example Programs", "index.html#PolyhedronAdvanced", [
        [ "Example Creating a Subdivision Surface", "index.html#PolyhedronExampleCreatingaSubdivisionSurface", null ],
        [ "Example Using the Incremental Builder and Modifier Mechanism", "index.html#PolyhedronExampleUsingtheIncrementalBuilder", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Polyhedron_2draw_polyhedron_8cpp-example.html",
"classCGAL_1_1Polyhedron__traits__with__normals__3.html#ae9d437809ba475201dd77f67ee328fd8"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.2-doc_html.tar.xz: doc_html/Polyhedron/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2 - 3D Polyhedral Surface", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#sectionPolyIntro", null ],
      [ "Definition", "index.html#PolyhedronDefinition", null ],
      [ "Example Programs", "index.html#PolyhedronExample", [
        [ "First Example Using Defaults", "index.html#PolyhedronFirstExampleUsingDefaults", null ],
        [ "Example with Geometry in Vertices", "index.html#PolyhedronExamplewithGeometryinVertices", null ],
        [ "Example for Affine Transformation", "index.html#PolyhedronExampleforAffineTransformation", null ],
        [ "Example Computing Plane Equations", "index.html#PolyhedronExampleComputingPlaneEquations", null ],
        [ "Example with a Vector Instead of a List Representation", "index.html#sectionPolyVector", null ],
        [ "Example with Circulator Writing Object File Format (OFF)", "index.html#PolyhedronExamplewithCirculatorWritingObject", null ],
        [ "Example Using Euler Operators to Build a Cube", "index.html#PolyhedronExampleUsingEulerOperatorstoBuild", null ],
        [ "Draw a Polyhedron", "index.html#PolyhedronDraw", null ]
      ] ],
      [ "File I/O", "index.html#PolyhedronFile", null ],
      [ "Extending Vertices, Halfedges, and Facets", "index.html#PolyhedronExtending", null ],
      [ "Advanced Example Programs", "index.html#PolyhedronAdvanced", [
        [ "Example Creating a Subdivision Surface", "index.html#PolyhedronExampleCreatingaSubdivisionSurface", null ],
        [ "Example Using the Incremental Builder and Modifier Mechanism", "index.html#PolyhedronExampleUsingtheIncrementalBuilder", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Polyhedron_2draw_polyhedron_8cpp-example.html",
"classCGAL_1_1Polyhedron__traits__3.html#a3c32c38bd9fc0b5a1880ed68512802f0"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
